@@ -70,14 +70,33 @@ class BlocksEndpoint(Endpoint):
             method="PATCH",
             body=pick(
                 kwargs,
-                "paragraph",
                 "heading_1",
+                "type",
+                "archived",
                 "heading_2",
                 "heading_3",
+                "embed",
+                "bookmark",
+                "image",
+                "video",
+                "pdf",
+                "file",
+                "audio",
+                "code",
+                "equation",
+                "divider",
+                "breadcrumb",
+                "table_of_contents",
+                "link_to_page",
+                "paragraph",
                 "bulleted_list_item",
                 "numbered_list_item",
-                "toggle",
+                "quote",
                 "to_do",
+                "toggle",
+                "template",
+                "callout",
+                "synced_block",
             ),
             auth=kwargs.get("auth"),
         )
@@ -97,7 +116,15 @@ class BlocksEndpoint(Endpoint):
 
 class DatabasesEndpoint(Endpoint):
     def list(self, **kwargs: Any) -> SyncAsync[Any]:
-        """List all Databases shared with the authenticated integration."""
+        """List all Databases shared with the authenticated integration.
+
+        > ⚠️  **Search pages for more details**
+        >
+        > This endpoint is no longer recommended, use search instead. This endpoint will
+        > only return explicitly shared pages, while search will also return child pages
+        > within explicitly shared pages. This endpoint's results cannot be filtered,
+        > while search can be used to match on page title.
+        """
         return self.parent.request(
             path="databases",
             method="GET",
@@ -143,7 +170,26 @@ class DatabasesEndpoint(Endpoint):
         )
 
 
+class PagesPropertiesEndpoint(Endpoint):
+    def retrieve(self, page_id: str, property_id: str, **kwargs: Any) -> SyncAsync[Any]:
+        """Retrieve a `property_item` object for a given `page_id` and `property_id`.
+
+        Depending on the property type, the object returned will either be a value or a
+        paginated list of property item values.
+        """
+        return self.parent.request(
+            path=f"pages/{page_id}/properties/{property_id}",
+            method="GET",
+            auth=kwargs.get("auth"),
+            query=pick(kwargs, "start_cursor", "page_size"),
+        )
+
+
 class PagesEndpoint(Endpoint):
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
+        self.properties = PagesPropertiesEndpoint(*args, **kwargs)
+
     def create(self, **kwargs: Any) -> SyncAsync[Any]:
         """Create a new page in the specified database or as a child of an existing page.
 
